@@ -11,7 +11,6 @@ import os
 import pathlib
 import random
 import re
-import requests
 import shutil
 import tempfile
 
@@ -21,7 +20,6 @@ import humanfriendly
 import pyxllib.stdlib.zipfile as zipfile  # 重写了标准库的zipfile文件，cp437改为gbk，解决zip中文乱码问题
 from pyxllib.algo.pupil import natural_sort
 from pyxllib.text.pupil import strfind
-from pyxllib.time.specialist.datetime import Datetime
 from pyxllib.debug.pupil import dprint
 from pyxllib.file.specialist import get_etag, PathBase, File
 
@@ -230,7 +228,7 @@ class Dir(PathBase):
 
         """
         from pyxllib.debug.specialist.xllog import Iterate
-        
+
         if ref_dir:
             ref_dir = Dir(ref_dir)
             paths1 = self.subpaths()
@@ -357,6 +355,7 @@ def filesfilter(files, *, root=os.curdir, type_=None,
     :param max_mtime: ~
     :return:
     """
+    from pyxllib.debug.specialist.datetime import Datetime
 
     def judge(f):
         if root: f = os.path.join(root, f)
@@ -819,18 +818,3 @@ class PackFile:
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.clear_tempfolder()
-
-
-def download_file(url, fn=None, *, encoding=None, if_exists=None, ext=None, temp=False):
-    """类似writefile，只是源数据是从url里下载
-    :param url: 数据下载链接
-    :param fn: 保存位置，会从url智能提取文件名
-    :param if_exists: 详见writefile参数解释
-    :para temp: 将文件写到临时文件夹
-    :return:
-    """
-    if not fn: fn = url.split('/')[-1]
-    root = Dir.TEMP if temp else None
-    fn = File(fn, root, suffix=ext).write(requests.get(url).content,
-                                          encoding=encoding, if_exists=if_exists, etag=(not fn))
-    return fn.to_str()
