@@ -25,7 +25,6 @@ import yaml
 
 from pyxllib.algo.pupil import Groups
 from pyxllib.file.pupil import struct_unpack, gen_file_filter
-from pyxllib.time.specialist.datetime import Datetime
 from pyxllib.prog.pupil import is_url, is_file
 
 ____judge = """
@@ -47,7 +46,12 @@ ____qiniu = """
 
 def get_etag(arg):
     """七牛原有etag功能基础上做封装
+
     :param arg: 支持bytes二进制、文件、url地址
+
+    只跟文件内容有关，跟文件创建、修改日期没关系
+    如果读取文件后再处理etag，要尤其小心 '\r\n' 的问题！
+    文件里如果是\r\n，我的File.read会变成\n，所以按文件取etag和read的内容算etag会不一样。
     """
     if isinstance(arg, bytes):  # 二进制数据
         return qiniu.utils.etag_stream(io.BytesIO(arg))
@@ -76,6 +80,7 @@ def test_etag():
 
 def test_etag2():
     """ 字符串值和写到文件判断的etag，是一样的
+
     """
     s = 'code4101'
     print(get_etag(s))
@@ -171,7 +176,7 @@ def get_encoding(bstr, *, maxn=100):
     enc = chardet.detect(bstr[start_idx:start_idx + maxn])['encoding']
 
     # 2 转换为常见编码名
-    if enc in ('utf-8', 'ascii', 'ISO-8859-1', 'Windows-1252', 'Windows-1254', 'ISO-8859-9'):
+    if enc in ('utf-8', 'ascii', 'ISO-8859-1', 'Windows-1252', 'Windows-1254', 'ISO-8859-9', 'IBM866'):
         return 'utf8'
     elif enc in ('UTF-8-SIG',):
         return 'utf-8-sig'
@@ -377,21 +382,23 @@ class PathBase:
         return g.group(1) if g else ''
 
     @property
-    def mtime(self) -> Datetime:
+    def mtime(self):
         r""" 文件的最近修改时间
 
         >> Path(r"C:\pycode\code4101py").mtime
         2020-03-10 17:32:37
         """
+        from pyxllib.debug.specialist.datetime import Datetime
         return Datetime(os.stat(str(self)).st_mtime)
 
     @property
-    def ctime(self) -> Datetime:
+    def ctime(self):
         r""" 文件的创建时间
 
         >> Path(r"C:\pycode\code4101py").ctime
         2018-05-25 10:46:37
         """
+        from pyxllib.debug.specialist.datetime import Datetime
         # 注意：st_ctime是平台相关的值，在windows是创建时间，但在Unix是metadate最近修改时间
         return Datetime(os.stat(str(self)).st_ctime)
 
@@ -1117,6 +1124,7 @@ def genfilename(fd='.'):
         后面的6位记为数值d2，类似小时+分钟+秒的标签，但是在出现重名时，
         d2会一直自加1直到没有重名文件，所以秒上是可能会出现“99”之类的值的。
     """
+    from pyxllib.debug.specialist.datetime import Datetime
     # 1 获取前段标签
     s1 = Datetime().briefdateweek()  # '180827周一'
 
