@@ -24,17 +24,18 @@ except ModuleNotFoundError:
     import keyboard
 
 import pyscreeze  # NOQA pyautogui安装的时候会自动安装依赖的pyscreeze
+import imagehash
 
 import numpy as np
 from pandas.api.types import is_list_like
 
-from pyxllib.time.specialist import TicToc
-from pyxllib.file.specialist import File, Dir
-from pyxllib.prog.newbie import first_nonnone
-from pyxllib.prog.pupil import xlwait
-from pyxllib.cv.specialist import imread, imwrite, get_sub_image, pil2cv
+from pyxllib.debug.specialist import TicToc
+from pyxllib.file.specialist import File, Dir, get_etag
+from pyxllib.prog.newbie import first_nonnone, round_int
+from pyxllib.prog.pupil import xlwait, DictTool
+from pyxllib.cv.expert import imread, imwrite, get_sub_image, pil2cv, cv2pil
 from pyxllib.algo.geo import ComputeIou, shapely_polygon, ltrb2xywh, xywh2ltrb
-from pyxllib.data.label import LabelmeData
+from pyxllib.data.labelme import LabelmeData
 
 
 class AutoGuiLabelData:
@@ -66,17 +67,8 @@ class AutoGuiLabelData:
     def parse_shape(cls, shape, image=None):
         """ 解析一个shape的数据为dict字典 """
         # 1 解析原label为字典
-        label = shape['label']
-        attrs = shape.copy()
-        try:
-            data = json.loads(label)
-            if isinstance(data, dict):
-                attrs.update(data)
-        except json.decoder.JSONDecodeError:
-            pass
-        # 如果label是普通字符串，则labelattr强升为字典
-        if not attrs:
-            attrs['label'] = label
+        attrs = DictTool.json_loads(shape['label'], 'label')
+        attrs.update(DictTool.sub(shape, ['label']))
 
         # 2 中心点 center
         shape_type = shape['shape_type']
@@ -92,7 +84,7 @@ class AutoGuiLabelData:
         elif shape_type == 'circle':
             x, y = pts[0]
             r = ((x - pts[1][0]) ** 2 + (y - pts[1][1]) ** 2) ** 0.5
-            attrs['ltrb'] = [int(v) for v in [x - r, y - r, x + r, y + r]]
+            attrs['ltrb'] = [round_int(v) for v in [x - r, y - r, x + r, y + r]]
 
         # 4 图片数据 img, etag
         if image is not None and attrs['ltrb']:
@@ -155,8 +147,7 @@ class AutoGuiLabelData:
         lmdict = LabelmeData.gen_data(imfile)
         for label, ann in self.data[loc].items():
             a = ann.copy()
-            if 'img' in a:
-                del a['img']
+            DictTool.isub(a, ['img'])
             shape = LabelmeData.gen_shape(json.dumps(a, ensure_ascii=False),
                                           a['points'], a['shape_type'],
                                           group_id=a['group_id'], flags=a['flags'])
@@ -225,7 +216,7 @@ class NamedLocate(AutoGuiLabelData):
         self.last_shot = self.screenshot(region)
         return self.last_shot
 
-    def point2pixel(self, point):
+    def point2pixel(self, point, haystack=None):
         """
 
         :param point: 支持输入 (x, y) 坐标，或者 loclabel
@@ -236,16 +227,20 @@ class NamedLocate(AutoGuiLabelData):
         """
         if isinstance(point, str):
             point = self[point]['center']
-        return tuple(self.last_shot[point[1], point[0]].tolist()[::-1])
+        if haystack is None:
+            haystack = self.update_shot()
+        return tuple(haystack[point[1], point[0]].tolist()[::-1])
 
-    def rect2img(self, ltrb):
+    def rect2img(self, ltrb, haystack=None):
         """
         :param ltrb: 可以输入坐标定位，也可以输入 loclabel 定位
         """
         if isinstance(ltrb, str):
             ltrb = self[ltrb]['ltrb']
         l, t, r, b = ltrb
-        return self.last_shot[t:b, l:r]
+        if haystack is None:
+            haystack = self.update_shot()
+        return haystack[t:b, l:r]
 
     @classmethod
     def pixel_distance(cls, pixel1, pixel2):
@@ -261,27 +256,32 @@ class NamedLocate(AutoGuiLabelData):
         cmp = np.array(abs(np.array(img1, dtype=int) - img2) > tolerance)
         return cmp.sum() / cmp.size
 
-    def check_pixel(self, loclabel, *, tolerance=None):
+    def check_pixel(self, loclabel, haystack=None, *, tolerance=None):
         """ 判断对应位置上的像素值是否相同
         """
         tolerance = first_nonnone([tolerance, self.tolerance, 20])
         p1 = self[loclabel]['pixel']
-        p2 = self.point2pixel(loclabel)
+        p2 = self.point2pixel(loclabel, haystack)
         return self.pixel_distance(p1, p2) < tolerance
 
-    def check_img(self, loclabel, img=None, *, grayscale=None, confidence=None):
+    def check_img(self, loclabel, needle=None, *, grayscale=None, confidence=None):
         grayscale = first_nonnone([grayscale, self.grayscale, False])
         confidence = first_nonnone([confidence, self.confidence, 0.95])
-        if img is None:
-            img = self[loclabel]['img']
-        elif isinstance(img, str):
-            img = self[img]['img']
-        boxes = pyautogui.locateAll(img, self.screenshot(loclabel),
-                                    grayscale=grayscale, confidence=confidence)
-        boxes = [xywh2ltrb(box) for box in list(boxes)]
-        return len(boxes)
+        if needle is None:
+            needle = self[loclabel]['img']
+        elif isinstance(needle, str):
+            needle = self[needle]['img']
+        haystack = self.screenshot(loclabel)
 
-    def img2rects(self, img, *, grayscale=None, confidence=None):
+        if confidence >= 1:
+            return np.array_equal(needle, haystack)
+        else:
+            boxes = pyautogui.locateAll(needle, self.screenshot(loclabel),
+                                        grayscale=grayscale, confidence=confidence)
+            boxes = [xywh2ltrb(box) for box in list(boxes)]
+            return len(boxes)
+
+    def img2rects(self, img, haystack=None, *, grayscale=None, confidence=None):
         """ 根据预存的img数据，匹配出多个内容对应的所在的rect位置 """
         # 1 配置参数
         if isinstance(img, str):
@@ -289,31 +289,35 @@ class NamedLocate(AutoGuiLabelData):
         grayscale = first_nonnone([grayscale, self.grayscale, False])
         confidence = first_nonnone([confidence, self.confidence, 0.95])
         # 2 查找子图
-        self.update_shot()
-        boxes = pyautogui.locateAll(img, self.last_shot,
+        if haystack is None:
+            self.update_shot()
+            haystack = self.last_shot
+        boxes = pyautogui.locateAll(img, haystack,
                                     grayscale=grayscale,
                                     confidence=confidence)
         # 3 过滤掉重叠超过一半面积的框
         return ComputeIou.nms_ltrb([xywh2ltrb(box) for box in list(boxes)])
 
-    def img2rect(self, img, *, grayscale=None, confidence=None):
+    def img2rect(self, img, haystack=None, *, grayscale=None, confidence=None):
         """ img2rects的简化，只返回一个匹配框
         """
-        rects = self.img2rects(img, grayscale=grayscale, confidence=confidence)
+        rects = self.img2rects(img, haystack, grayscale=grayscale, confidence=confidence)
         return rects[0] if rects else None
 
-    def img2point(self, img, *, grayscale=None, confidence=None):
+    def img2point(self, img, haystack=None, *, grayscale=None, confidence=None):
         """ 将 img2rect 的结果统一转成点 """
-        res = self.img2rect(img, grayscale=grayscale, confidence=confidence)
+        res = self.img2rect(img, haystack, grayscale=grayscale, confidence=confidence)
         if res:
             return np.array(np.array(res).reshape(2, 2).mean(axis=0), dtype=int).tolist()
 
-    def img2img(self, img, *, grayscale=None, confidence=None):
+    def img2img(self, img, haystack=None, *, grayscale=None, confidence=None):
         """ 找到rect后，返回匹配的目标img图片内容 """
-        ltrb = self.img2rect(img, grayscale=grayscale, confidence=confidence)
+        ltrb = self.img2rect(img, haystack, grayscale=grayscale, confidence=confidence)
         if ltrb:
             l, t, r, b = ltrb
-            return self.last_shot[t:b, l:r]
+            if haystack is not None:
+                haystack = self.last_shot
+            return haystack[t:b, l:r]
 
     def click(self, point, *, back=False, wait_change=False):
         """
